@@ -16,6 +16,7 @@ from matplotlib import ticker
 from pathlib import Path
 
 sns.set()
+plt.switch_backend("agg")
 
 
 class Plot:
@@ -27,6 +28,7 @@ class Plot:
 
     def read_length_distribution(self) -> None:
         # Reads length distribution
+        sns.set_style("white")
         plt.figure(dpi=300, figsize=(9, 5))
         read = pd.read_table(f"{self.samprefix}.freq.stat", sep="\t", header=None, skipfooter=1, engine="python")
         read.columns = ["Read length", "count", "Read count percentage"]
@@ -38,6 +40,7 @@ class Plot:
 
     def read_type_distribution_hist(self) -> None:
         # Read type distribution
+        sns.set_style("white")
         plt.figure(dpi=300, figsize=(9, 5))
         ncrna_type = pd.read_table(f"{self.samprefix}.stat", header=None, sep="\t", skiprows=4, dtype=str)
         ncrna_type.columns = ["Category", "MappingTag", "Ratio"]
@@ -50,7 +53,7 @@ class Plot:
         read_type.get_figure().savefig(f"{self.outputdir}/distribution_of_ncRNA_type.pdf")
 
     def read_type_distribution_pie(self) -> None:
-        plt.figure(dpi=300, figsize=(7, 5))
+        plt.figure(dpi=300, figsize=(8, 8))
         read_type_pie = pd.read_table(f"{self.samprefix}.stat", header=None, sep="\t", skiprows=4, dtype=str)
         read_type_pie.columns = ["Category", "MappingTag", "Ratio"]
         read_type_pie["Ratio"] = read_type_pie["Ratio"].apply(lambda x: np.nan if x in ["-"] else x[:-1]).astype(float)
@@ -61,7 +64,7 @@ class Plot:
         all_category = list(read_type_pie["Category"]) + ["unmapped"]
         all_labels = ["{0} - {1:1.2f}%".format(i, j) for i, j in zip(all_category, all_ratio)]
         plt.pie(all_ratio)
-        plt.legend(labels=all_labels, bbox_to_anchor=(1.15, 0.5), loc="center", frameon=False, fontsize=7)
+        plt.legend(labels=all_labels, bbox_to_anchor=(1.05, 0.5), loc="center", frameon=False, fontsize=7)
         # save image
         plt.savefig(f"{self.outputdir}/distribution_of_ncRNA_type_pie.png")
         plt.savefig(f"{self.outputdir}/distribution_of_ncRNA_type_pie.pdf")
